@@ -38,7 +38,8 @@ impl Storage for ProgramData {
                     e.get_mut().ref_count += var_info.ref_count;
                     e.get_mut().cond_init |= var_info.cond_init;
 
-                    e.get_mut().reassigned |= var_info.reassigned;
+                    e.get_mut().reassigned_with_assignment |= var_info.reassigned_with_assignment;
+                    e.get_mut().reassigned_with_var_decl |= var_info.reassigned_with_var_decl;
                     e.get_mut().mutated |= var_info.mutated;
 
                     e.get_mut().has_property_access |= var_info.has_property_access;
@@ -107,15 +108,21 @@ impl Storage for ProgramData {
         has_init: bool,
         kind: Option<VarDeclKind>,
     ) -> &mut VarUsageInfo {
-        // tracing::trace!("declare_decl({}{:?})", i.sym, i.span.ctxt);
+        if cfg!(feature = "debug") {
+            tracing::debug!(has_init = has_init, "declare_decl(`{}`)", i);
+        }
 
         let v = self
             .vars
             .entry(i.to_id())
             .and_modify(|v| {
                 if has_init && v.declared {
+                    if cfg!(feature = "debug") {
+                        tracing::debug!("declare_decl(`{}`): Already declared", i);
+                    }
+
                     v.mutated = true;
-                    v.reassigned = true;
+                    v.reassigned_with_var_decl = true;
                     v.assign_count += 1;
                 }
 
@@ -186,7 +193,7 @@ impl ProgramData {
         if is_first {
             e.ref_count += 1;
         }
-        e.reassigned |= is_first && is_modify && ctx.is_exact_reassignment;
+        e.reassigned_with_assignment |= is_first && is_modify && ctx.is_exact_reassignment;
         // Passing object as a argument is possibly modification.
         e.mutated |= is_modify || (ctx.in_call_arg && ctx.is_exact_arg);
         e.executed_multiple_time |= ctx.executed_multiple_time;
@@ -245,8 +252,8 @@ impl VarDataLike for VarUsageInfo {
         self.mutated = true;
     }
 
-    fn mark_reassigned(&mut self) {
-        self.reassigned = true;
+    fn mark_reassigned_with_assign(&mut self) {
+        self.reassigned_with_assignment = true;
     }
 
     fn add_infects(&mut self, other: Id) {
